@@ -3,7 +3,7 @@
     Pygments tests for using()
     ~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-    :copyright: Copyright 2006-2009 by the Pygments team, see AUTHORS.
+    :copyright: Copyright 2006-2017 by the Pygments team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
@@ -32,7 +32,7 @@ class UsingStateTest(unittest.TestCase):
         expected = [(Text, 'a'), (String, '"'), (Keyword, 'bcd'),
                     (String, '"'), (Text, 'e\n')]
         t = list(TestLexer().get_tokens('a"bcd"e'))
-        self.assertEquals(t, expected)
+        self.assertEqual(t, expected)
 
     def test_error(self):
         def gen():
